import {getDeviceKnownData} from 'sentry/components/events/contexts/device/getDeviceKnownData';

import {deviceContextMetaMockData, deviceMockData} from './index.spec';

describe('getDeviceKnownData', function () {
  it('filters data and transforms into the right way', function () {
    const deviceKnownData = getDeviceKnownData({
      data: deviceMockData,
      meta: deviceContextMetaMockData,
      event: TestStubs.Event(),
    });

    expect(deviceKnownData).toEqual([
      {
        key: 'name',
        subject: 'Name',
        value: '',
        meta: deviceContextMetaMockData.name[''],
        subjectDataTestId: 'device-context-name-value',
      },
      {
        key: 'family',
        subject: 'Family',
        value: 'Android',
        meta: undefined,
        subjectDataTestId: 'device-context-family-value',
      },
      {
        key: 'arch',
        subject: 'Architecture',
        value: 'x86',
        meta: undefined,
        subjectDataTestId: 'device-context-arch-value',
      },
      {
        key: 'battery_level',
        subject: 'Battery Level',
        value: '100%',
        meta: undefined,
        subjectDataTestId: 'device-context-battery_level-value',
      },
      {
        key: 'orientation',
        subject: 'Orientation',
        value: 'portrait',
        meta: undefined,
        subjectDataTestId: 'device-context-orientation-value',
      },
      {
        key: 'memory_size',
        subject: 'Memory Size',
        value: expect.anything(),
        meta: undefined,
        subjectDataTestId: 'device-context-memory_size-value',
      },
      {
        key: 'free_memory',
        subject: 'Free Memory',
        value: expect.anything(),
        meta: undefined,
        subjectDataTestId: 'device-context-free_memory-value',
      },
      {
        key: 'low_memory',
        subject: 'Low Memory',
        value: false,
        meta: undefined,
        subjectDataTestId: 'device-context-low_memory-value',
      },
      {
        key: 'storage_size',
        subject: 'Storage Size',
        value: expect.anything(),
        meta: undefined,
        subjectDataTestId: 'device-context-storage_size-value',
      },
      {
        key: 'external_storage_size',
        subject: 'External Storage Size',
        value: expect.anything(),
        meta: undefined,
        subjectDataTestId: 'device-context-external_storage_size-value',
      },
      {
        key: 'external_free_storage',
        subject: 'External Free Storage',
        value: expect.anything(),
        meta: undefined,
        subjectDataTestId: 'device-context-external_free_storage-value',
      },
      {
        key: 'free_storage',
        subject: 'Free Storage',
        value: expect.anything(),
        meta: undefined,
        subjectDataTestId: 'device-context-free_storage-value',
      },
      {
        key: 'simulator',
        subject: 'Simulator',
        value: true,
        meta: undefined,
        subjectDataTestId: 'device-context-simulator-value',
      },
      {
        key: 'boot_time',
        subject: 'Boot Time',
        value: expect.anything(),
        meta: undefined,
        subjectDataTestId: 'device-context-boot_time-value',
      },
      {
        key: 'timezone',
        subject: 'Timezone',
        value: 'America/Los_Angeles',
        meta: undefined,
        subjectDataTestId: 'device-context-timezone-value',
      },
      {
        key: 'archs',
        subject: 'Architectures',
        value: expect.anything(),
        meta: undefined,
        subjectDataTestId: 'device-context-archs-value',
      },
      {
        key: 'brand',
        subject: 'Brand',
        value: 'google',
        meta: undefined,
        subjectDataTestId: 'device-context-brand-value',
      },
      {
        key: 'charging',
        subject: 'Charging',
        value: true,
        meta: undefined,
        subjectDataTestId: 'device-context-charging-value',
      },
      {
        key: 'manufacturer',
        subject: 'Manufacturer',
        value: 'Google',
        meta: undefined,
        subjectDataTestId: 'device-context-manufacturer-value',
      },
      {
        key: 'online',
        subject: 'Online',
        value: true,
        meta: undefined,
        subjectDataTestId: 'device-context-online-value',
      },
      {
        key: 'screen_density',
        subject: 'Screen Density',
        value: 3,
        meta: undefined,
        subjectDataTestId: 'device-context-screen_density-value',
      },
      {
        key: 'screen_dpi',
        subject: 'Screen DPI',
        value: 480,
        meta: undefined,
        subjectDataTestId: 'device-context-screen_dpi-value',
      },
      {
        key: 'screen_resolution',
        subject: 'Screen Resolution',
        value: '1136x768',
        meta: undefined,
        subjectDataTestId: 'device-context-screen_resolution-value',
      },
      {
        key: 'screen_height_pixels',
        subject: 'Screen Height Pixels',
        value: 1136,
        meta: undefined,
        subjectDataTestId: 'device-context-screen_height_pixels-value',
      },
      {
        key: 'screen_width_pixels',
        subject: 'Screen Width Pixels',
        value: 768,
        meta: undefined,
        subjectDataTestId: 'device-context-screen_width_pixels-value',
      },
      {
        key: 'model',
        subject: 'Model',
        value: expect.anything(),
        meta: undefined,
        subjectDataTestId: 'device-context-model-value',
      },
      {
        key: 'model_id',
        subject: 'Model Id',
        value: 'NYC',
        meta: undefined,
        subjectDataTestId: 'device-context-model_id-value',
      },
    ]);
  });
});
